
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-06-07T14:57:02-0700",
 "dirty": true,
 "error": null,
 "full-revisionid": "04d99c419e1b2cc7b9a3dc3e6fe9cb325993dffb",
 "version": "0.6.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
